#
# spec file for package python-orjson
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-orjson
Version:        3.8.10
Release:        2.3
Summary:        Fast, correct Python JSON library supporting dataclasses, datetimes, and numpy
License:        Apache-2.0 OR MIT
URL:            https://github.com/ijl/orjson
Source:         https://files.pythonhosted.org/packages/source/o/orjson/orjson-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  %{python_module maturin >= 0.12.19}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pendulum}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module xxhash}
BuildRequires:  timezone
# /SECTION
%python_subpackages

%description
orjson is a fast JSON library for Python.
It benchmarks as the fastest Python library for JSON.

%prep
%autosetup -a1 -n orjson-%{version}
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# test_numpy_array_d1_uintp and test_numpy_array_d1_intp fail on 32bit
# test_memory_loads_keys occasionally fails on crashes on ppc64le
%pytest_arch -k "not (test_numpy_array_d1_intp or test_numpy_array_d1_uintp or test_memory_loads_keys)"

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE-APACHE LICENSE-MIT
%{python_sitearch}/orjson*

%changelog
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Update to 3.8.10:
  - Fix compatibility with CPython 3.12.0a7.
  - Fix compatibility with big-endian architectures.
  - Fix crash in serialization.
  - Fix parallel initialization of orjson.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 3.8.3:
  * `orjson.dumps()` accepts `option=None` per `Optional[int]` type.
  * Fix tests on 32-bit for `numpy.intp` and `numpy.uintp`.
  * Build now depends on rustc 1.60 or later.
  * Support building with maturin 0.13 or 0.14.
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.8.1
  - Build maintenance for Python 3.11.
* Wed Sep 21 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.8.0:
  - Support serializing numpy.int16 and numpy.uint16.
  - Fix datetime regression tests with tzinfo 2022b.
* Wed Sep 21 2022 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Tidy spec
* Wed Jul 13 2022 Adrian Schröter <adrian@suse.de>
- initial package of version 3.7.7
